Lua_OpenServerHeroComeWindow = class("Lua_OpenServerHeroComeWindow", Lua_Window)
function Lua_OpenServerHeroComeWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_OpenServerHeroComeWindow";
	self.skinName = "OpenServerHeroComeWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_OpenServerHeroComeWindow:dispose()
	if self.taskItemArr ~= nil then
		self.taskItemArr:dispose();
		self.taskItemArr:clear();
		self.taskItemArr = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self:removeShowModel();
	self:shopActiveTime();
	self:superCall("dispose");
end

function Lua_OpenServerHeroComeWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.taskItemArr = Array();

	self:addLuaEvent("UPDATE_HEROCOME_SHOWINFO", self, self.updateTaskInfo);
	self:addLuaEvent("HEROCOME_SHOW_NEWHERO", self, self.showNewHero);
	self.drawBtn:addClickFuntion(self, self.drawHero);
	self.checkHeroBtn:addClickFuntion(self, self.showHero);

	Lua_ProxyManager.getProxy("Lua_OpenServerTrialProxy"):sHeroComeInfo()
end

function Lua_OpenServerHeroComeWindow:showActiveTime()
	self.leftTime = DataCenter.openServerHeroComeData.activeTime - DataCenter.roleData.serverTime;
	self:onTimeDown();
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("OnHeroComeTimer", 1, self, self.onTimeDown);
	end
end

function Lua_OpenServerHeroComeWindow:shopActiveTime()
	if self.bTimer == true then
		self.bTimer = false;
		Lua_CommonUtil.removeTimer(self, self.onTimeDown);
	end
end

function Lua_OpenServerHeroComeWindow:onTimeDown()
	if self.leftTime <= 0 then
		self.timeTxt:setLangValue(670007);
		self:shopActiveTime();
		return;
	end
	local str = Lua_TimeTransform.transSeconds18(self.leftTime, true, true, true, true);
	self.timeTxt.text = LanUtil.formateStr(670000, str);
	self.leftTime = self.leftTime - 1;
end

function Lua_OpenServerHeroComeWindow:updateTaskInfo()
	local list = DataCenter.openServerHeroComeData.taskVoList;
	local drawState = DataCenter.openServerHeroComeData.heroDrawState;
	if list == nil then
		return;
	end

	local process = 0;
	local taskItem;
	local taskCount = #list;
	for i = 1, taskCount do
		taskItem = self.taskItemArr[i];
		if taskItem == nil then
			taskItem = Lua_OpenServerHeroComeTaskItem.new(self.content);
			taskItem:setLocation(-226 + (i - 1) * 225, -226);
			self.taskItemArr:add(taskItem);
		end
		taskItem:setData(list[i]);
		if list[i].state ~= 0 then
			process = process + 1;
		end
	end

	local str;
	if process < taskCount then
		str = Lua_ColorDefine.getColorStr("FF2E00", process);
	else
		str = Lua_ColorDefine.getColorStr("2CE654", process);
	end
	self.processTxt.text = LanUtil.formateStr(670001, str, taskCount);
	if drawState == 1 then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setLocation(-200, 57);
		end
	end
	if self.redPoint ~= nil then
		self.redPoint:updateRedPointShow(drawState == 1);
	end

	self:showActiveTime();
end

function Lua_OpenServerHeroComeWindow:drawHero()
	if not DataCenter.funcOpenData:isOpened(10283) then
		OperateAlert.showLangValue(670008);
		return;
	end
	local state = DataCenter.openServerHeroComeData.heroDrawState;
	if state == 1 then
		Lua_ProxyManager.getProxy("Lua_OpenServerTrialProxy"):sHeroComeDrawHero();
	elseif state == 0 then
		OperateAlert.showLangValue(670004);
	else
		OperateAlert.showLangValue(670005);
	end
end

function Lua_OpenServerHeroComeWindow:showHero()
	local heroId = DataCenter.openServerHeroComeData.heroId;
	DataCenter.heroAtlasData:onOpenAtlasWindow(heroId, 1);
end

function Lua_OpenServerHeroComeWindow:showNewHero(msg)
	if msg == nil or msg.is_new ~= 1 then
		return;
	end
	self.bShowNewHero = true;
	local heroId = DataCenter.openServerHeroComeData.heroId;
	local heroVo = Lua_HeroVo.new(heroId);
    DataCenter.preLoadData:preShowModelScene("Lua_RecruitShowSingleHeroWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onShowModel, heroVo, heroVo);
end

function Lua_OpenServerHeroComeWindow:onShowModel(param)
    Lua_WindowUtil.openWin("Lua_RecruitShowSingleHeroWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_OpenServerHeroComeWindow:removeShowModel()
	if self.bShowNewHero == true then
		DataCenter.preLoadData:removeBySign("Lua_RecruitShowSingleHeroWindow", self, self.onShowModel);
	end
end










Lua_OpenServerHeroComeTaskItem = class("Lua_OpenServerHeroComeTaskItem", Lua_DisplayObject)
function Lua_OpenServerHeroComeTaskItem:ctor(p)
	self:superCall("ctor", p, "OpenServerHeroComeTaskItem_skin");
end

function Lua_OpenServerHeroComeTaskItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_OpenServerHeroComeTaskItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setLocation(0, 80);
	self.itemIcon:setScale(0.74, 0.74);
	self.itemIcon:setCanClick(true);
    
    self.drawSp.siblingIndex = 4;
	self.drawBtn:addClickFuntion(self, self.drawReward);
end

function Lua_OpenServerHeroComeTaskItem:setData(data)
	self.data = data;
	if data.showReward ~= nil then
		local tvo = Lua_ToolVo.createToolVo(data.showReward[1], data.showReward[2]);
		self.itemIcon:setData(tvo);
	end

    local str;
	if data.state == 0 then
		self.drawBtn:setLangValue(670002);
		self.drawBtn:setStyle(7);
		self.bg:setAltas("openServerTrial_atlas", "xui_kfyx_window_8");
		str = Lua_ColorDefine.getColorStr("ed4c30", data.curProcess);
	elseif data.state == 1 then
		self.drawBtn:setLangValue(670003);
		self.drawBtn:setStyle(5);
		self.bg:setAltas("openServerTrial_atlas", "xui_kfyx_window_9");
		str = Lua_ColorDefine.getColorStr("479154", data.curProcess);
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setLocation(58, -91);
		end
	else
		self.bg:setAltas("openServerTrial_atlas", "xui_kfyx_window_8");
		str = Lua_ColorDefine.getColorStr("479154", data.curProcess);
	end
	if self.redPoint ~= nil then
		self.redPoint:updateRedPointShow(data.state == 1);
	end
	self.drawBtn:setEnable(data.state ~= 2);
    self.drawSp:setEnable(data.state == 2);
    self.itemIcon:setDrawMask(data.state == 2);
	self.descTxt.text = LanUtil.formateStr(data.desc, str);
end

function Lua_OpenServerHeroComeTaskItem:drawReward()
	if not DataCenter.funcOpenData:isOpened(10283) then
		OperateAlert.showLangValue(670008);
		return;
	end
    if self.data.state == 0 then
    	if self.data.eventId == nil then
    		if self.data.id == 1 then
    			--OperateAlert.showLangValue();
    		elseif self.data.id == 2 then
    			OperateAlert.showLangValue(670006);
    		elseif self.data.id == 3 then
    			--OperateAlert.showLangValue();
    		end
    		return;
    	end
		DataCenter.funcPathUtil:gotoFunction(self.data.eventId, true);
	elseif self.data.state == 1 then
		Lua_ProxyManager.getProxy("Lua_OpenServerTrialProxy"):sHeroComeDrawTask(self.data.id);
	end
end