-- 星河试炼排行榜
Lua_StarRiverTrialRankPanel = class("Lua_StarRiverTrialRankPanel", Lua_DisplayObject);
function Lua_StarRiverTrialRankPanel:ctor(p)
	self:superCall("ctor", p, "StarRiverTrialRankPanel_skin");
end

function Lua_StarRiverTrialRankPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.topRankArr = Array();
	self.rankArr = Array();

	self.itemList = Lua_DragList.new(self.content, 700, 540 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setListCell(Lua_StarRiverTrialRankItem, 688, 125, 1);
	self.itemList:setLocation(0, -172, 0);
	self.itemList:setCellSpacing(0, 10);

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setRectAnchor(7);
	self.avatarItem:setLocation(-148, 191, 0);
	self.avatarItem:setScale(0.7, 0.7);
	self.avatarItem:setCanClick(true);

	self.myNameTxt.text = DataCenter.roleData.name;

	self.rankNum = Lua_NumberImage.new(self.content);
	self.rankNum:setRectAnchor(7);
	self.rankNum:setLocation(-270, 186, 0);
	self.rankNum.pivot = 0;
	self.rankNum.numOffsetX = -2;
	self.rankNum.numAtlas = "number";
	self.rankNum.preStr = "xui_phb_number_";

	self:addLuaEvent("UPDATE_STARRIVERTRIAL_RANK_INFO", self, self.updateShowInfo);
	Lua_ProxyManager.getProxy("Lua_LimitedTimeActivityProxy"):sStarRiverTrialRankInfo();
end

function Lua_StarRiverTrialRankPanel:updateShowInfo()
	local myself_rank = DataCenter.starRiverTrialData.myself_rank;
	local rank_list = DataCenter.starRiverTrialData.rank_list;
	if myself_rank == nil or rank_list == nil then
		return;
	end
    
	self.myStarTxt.text = myself_rank.other_value;
	self.avatarItem:setRoleId(myself_rank.player_show.id);
	self.avatarItem:setRoleDressUp(myself_rank.player_show.dress_info, true);
	self.avatarItem:setRoleLevel2(myself_rank.player_show.level);

	if myself_rank.rank > DataCenter.starRiverTrialData.constConfig.show_panel_limit or myself_rank.rank == 0 then
		self.myNoneRankSp:setEnable(true);
		self.rankNum.num = nil;
	else
		self.myNoneRankSp:setEnable(false);
		self.rankNum.num = myself_rank.rank;
	end

	local posDic = {{1, -379}, {-235, -379}, {236, -379}};
	local item;
	for i = 1, 3 do
		item = self.topRankArr[i];
		if item == nil then
			item = Lua_StarRiverTrialTopRankItem.new(self.content);
			item:setRectAnchor(1);
			self.topRankArr:add(item);
		end
		item:setLocation(posDic[i][1], posDic[i][2]);
		item:setData(i, rank_list[i]);
	end

	for i = 4, #rank_list do
		self.rankArr:add(rank_list[i]);
	end
	self.itemList:setArrayData(self.rankArr);
    self.itemList:setEnable(#rank_list >= 4);
	self.noRankTxt:setEnable(#rank_list < 4);
	self.catImg:setEnable(#rank_list < 4);
	self:updateTime();
	if self.timeDown ~= true then
		self.timeDown = true;
		self:addTimer("StarRiverRankTimeDown", 1, self, self.updateTime);
	end
end

function Lua_StarRiverTrialRankPanel:updateTime()
	local remainTime = DataCenter.starRiverTrialData.close_tick - DataCenter.roleData.serverTime;
	if remainTime <= 0 then
		self.activeTimeTxt:setLangValue(510003);
		Lua_CommonUtil.removeTimer(self, self.updateTime);
		return;
	end
	local str = Lua_ColorDefine.getColorStr("3ffe43", Lua_TimeTransform.transSeconds18(remainTime, true, true, true, false));
	self.activeTimeTxt.text = LanUtil.formateStr(510005, str);
end

function Lua_StarRiverTrialRankPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.itemList:setContentRect(700, 540 + adaptHeight);
end

function Lua_StarRiverTrialRankPanel:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	if self.rankArr ~= nil then
		self.rankArr:dispose();
		self.rankArr:clear();
		self.rankArr = nil;
	end
	if self.topRankArr ~= nil then
		self.topRankArr:dispose();
		self.topRankArr:clear();
		self.topRankArr = nil;
	end

	Lua_CommonUtil.removeTimer(self, self.updateTime);

	self:superCall("dispose");
end





--------------------------------------------------





Lua_StarRiverTrialTopRankItem = class("Lua_StarRiverTrialTopRankItem", Lua_DisplayObject);
function Lua_StarRiverTrialTopRankItem:ctor(p)
	self:superCall("ctor", p, "StarRiverTrialTopRankItem_skin");
end

function Lua_StarRiverTrialTopRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
end

function Lua_StarRiverTrialTopRankItem:setData(rank, data)
	self.bg:setAltas("rank_altas", "xui_phb_bg_"..(rank + 1))

	local iconPosX = -16;
	if data == nil then
		self.nameTxt:setLangValue(510012);
		self.noRankHeadImg:setEnable(true);
		self.starTxt:setEnable(false);
		self.starIcon:setEnable(false);
	else
		self.avatarItem:setRoleDressUp(data.player_show.dress_info, true);
		self.avatarItem:setRoleLevel2(data.player_show.level);
		self.avatarItem:setRoleId(data.player_show.id);
		self.noRankHeadImg:setEnable(false);
        
		self.nameTxt.text = data.player_show.name;
		self.starTxt.text = data.other_value;
		self.starTxt:resetSize();
		local newWidth = self.starTxt.width;
		iconPosX = iconPosX - (newWidth - 16)/2;
	end

	if rank == 1 then
		self.avatarItem:setScale(0.9, 0.9);
		if data ~= nil then
			self.nameTxt:setLocation(0, -26);
		else
			self.nameTxt:setLocation(0, -52);
		end
		self.starIcon:setLocation(iconPosX, -68);
		self.starTxt:setLocation(9, -68);
		self.avatarItem:setLocation(0, 108);
		self.noRankHeadImg:setLocation(0, 108);
		self.rankTxt:setLocation(0, 26);
		self.rankTxt:setLangValue(510016);
		self.nameTxt.effectColorStr = Lua_ColorDefine.transColorStr("BE9565")
	else
		self.avatarItem:setScale(0.8, 0.8);
		if data ~= nil then
			self.nameTxt:setLocation(0, -13);
		else
			self.nameTxt:setLocation(0, -40);
		end
		self.starTxt:setLocation(9, -51);
		self.starIcon:setLocation(iconPosX, -51);
		self.avatarItem:setLocation(0, 96);
		self.noRankHeadImg:setLocation(0, 96);
		self.rankTxt:setLocation(0, 28);

		if rank == 2 then
			self.rankTxt:setLangValue(510017);
			self.nameTxt.effectColorStr = Lua_ColorDefine.transColorStr("767B85")
		else
			self.rankTxt:setLangValue(510018);
			self.nameTxt.effectColorStr = Lua_ColorDefine.transColorStr("A1827A")
		end
	end

	if rank == 1 then
		self.starTxt.effectColorStr = Lua_ColorDefine.transColorStr("BE9565");
	elseif rank == 2 then
		self.starTxt.effectColorStr = Lua_ColorDefine.transColorStr("767B85");
	else
		self.starTxt.effectColorStr = Lua_ColorDefine.transColorStr("A1827A");
	end

	self.avatarItem:setEnable(data ~= nil);
end

function Lua_StarRiverTrialTopRankItem:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_StarRiverTrialRankItem = class("Lua_StarRiverTrialRankItem", Lua_ListCell);
function Lua_StarRiverTrialRankItem:ctor(p)
    self:superCall("ctor", p, "StarRiverTrialRankItem_skin");
end

function Lua_StarRiverTrialRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setLocation(-140, 0, 0)
	self.avatarItem:setScale(0.7, 0.7);
end

function Lua_StarRiverTrialRankItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.numTxt.text = data.rank;
	self.nameTxt.text = data.player_show.name;
	self.valueTxt.text = data.other_value;

	self.avatarItem:setRoleDressUp(data.player_show.dress_info, true);
	self.avatarItem:setRoleLevel2(data.player_show.level);
end

function Lua_StarRiverTrialRankItem:onPressClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.mainContent);
	if self.avatarItem:checkInBound(winPos.x, winPos.y) then
		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(self.data.player_show.id, self.data.player_show.server_flag);
	end
end

function Lua_StarRiverTrialRankItem:dispose()
	self.data = nil;
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end

	self:superCall("dispose");
end